Documentation
¶
Index ¶
Constants ¶
const AUToKm = 149597870.7
AUToKm is the IAU 2012 nominal astronomical unit in kilometers.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Angle ¶
type Angle struct {
// contains filtered or unexported fields
}
Angle represents an angular measurement.
func AngleFromDegrees ¶
AngleFromDegrees creates an Angle from degrees.
func AngleFromHours ¶
AngleFromHours creates an Angle from hours of right ascension.
func (Angle) Arcminutes ¶
Arcminutes returns the angle in arcminutes.
func (Angle) Arcseconds ¶
Arcseconds returns the angle in arcseconds.
func (Angle) DMS ¶
DMS decomposes the angle into sign, integer degrees, integer arcminutes, and fractional arcseconds. Sign is +1 or -1.
func (Angle) HMS ¶
HMS decomposes the angle (as right ascension) into sign, integer hours, integer minutes, and fractional seconds. Sign is +1 or -1.
type Distance ¶
type Distance struct {
// contains filtered or unexported fields
}
Distance represents a distance measurement.
func DistanceFromAU ¶
DistanceFromAU creates a Distance from astronomical units.
func DistanceFromMeters ¶
DistanceFromMeters creates a Distance from meters.
func NewDistance ¶
NewDistance creates a Distance from kilometers.
func (Distance) LightSeconds ¶
LightSeconds returns the distance in light-seconds.